Module facet

Module facet 

Structs

FacetGroupKey
The key in the [facet_id_string_docids and facet_id_f64_docids][Index::facet_id_string_docids] databases.
FacetGroupKeyCodec
FacetGroupLazyValue
FacetGroupLazyValueCodec
FacetGroupValue
The value in the [facet_id_string_docids and facet_id_f64_docids][Index::facet_id_string_docids] databases.
FacetGroupValueCodec
FieldDocIdFacetCodec
OrderedF64Codec

Functions

try_split_at
Tries to split a slice in half at the given middle point, None if the slice is too short.

Type Aliases

FieldDocIdFacetF64Codec
FieldDocIdFacetIgnoreCodec
FieldDocIdFacetStringCodec
FieldIdCodec