pub enum DocumentId {
Retrieved {
value: String,
},
Generated {
value: String,
document_nth: u32,
},
}Expand description
A type that represents a document id that has been retrieved from a document or auto-generated.
In case the document id has been auto-generated, the document nth is kept to help users debug if there is an issue with the document itself.
Variants
Implementations
Sourceimpl DocumentId
impl DocumentId