#[non_exhaustive]pub enum IndexDocumentsMethod {
ReplaceDocuments,
UpdateDocuments,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReplaceDocuments
Replace the previous document with the new one, removing all the already known attributes.
UpdateDocuments
Merge the previous version of the document with the new version, replacing old attributes values with the new ones and add the new attributes.