pub enum UpdateIndexingStep {
RemapDocumentAddition {
documents_seen: usize,
},
ComputeIdsAndMergeDocuments {
documents_seen: usize,
total_documents: usize,
},
IndexDocuments {
documents_seen: usize,
total_documents: usize,
},
MergeDataIntoFinalDatabase {
databases_seen: usize,
total_databases: usize,
},
}Variants
RemapDocumentAddition
Remap document addition fields the one present in the database, adding new fields in to the schema on the go.
ComputeIdsAndMergeDocuments
This step check the external document id, computes the internal ids and merge the documents that are already present in the database.
IndexDocuments
Extract the documents words using the tokenizer and compute the documents facets. Stores those words, facets and documents ids on disk.
MergeDataIntoFinalDatabase
Merge the previously extracted data (words and facets) into the final LMDB database. These extracted data are split into multiple databases.
Implementations