try_split_array_at

Function try_split_array_at 

pub fn try_split_array_at<T, const N: usize>(
    slice: &[T],
) -> Option<([T; N], &[T])>
where [T; N]: for<'a> TryFrom<&'a [T]>,
Divides one slice into an array and the tail at an index, returns None if N is out of bounds.