pub struct DocumentAdditionResult {
pub indexed_documents: u64,
pub number_of_documents: u64,
}Fields
indexed_documents: u64The number of documents that were indexed during the update
number_of_documents: u64The total number of documents in the index after the update