pub struct FacetsUpdateBulk<'i> { /* private fields */ }Expand description
Algorithm to insert elememts into the facet_id_(string/f64)_docids databases
by rebuilding the database “from scratch”.
First, the new elements are inserted into the level 0 of the database. Then, the higher levels are cleared and recomputed from the content of level 0.
Implementations
Sourceimpl<'i> FacetsUpdateBulk<'i>
impl<'i> FacetsUpdateBulk<'i>
pub fn new( index: &'i Index, field_ids: Vec<FieldId>, facet_type: FacetType, delta_data: Merger<BufReader<File>, MergeDeladdCboRoaringBitmaps>, group_size: u8, min_level_size: u8, ) -> FacetsUpdateBulk<'i>
pub fn new_not_updating_level_0( index: &'i Index, field_ids: Vec<FieldId>, facet_type: FacetType, ) -> FacetsUpdateBulk<'i>
pub fn execute(self, wtxn: &mut RwTxn<'_>) -> Result<()>