pub struct FacetsUpdateIncrementalInner {
pub db: Database<FacetGroupKeyCodec<BytesRefCodec>, FacetGroupValueCodec>,
pub group_size: u8,
pub min_level_size: u8,
pub max_group_size: u8,
}Expand description
Implementation of FacetsUpdateIncremental that is independent of milli’s Index type
Fields
db: Database<FacetGroupKeyCodec<BytesRefCodec>, FacetGroupValueCodec>group_size: u8min_level_size: u8max_group_size: u8Implementations
Sourceimpl FacetsUpdateIncrementalInner
impl FacetsUpdateIncrementalInner
Sourcepub fn modify(
&self,
txn: &mut RwTxn<'_>,
field_id: u16,
facet_value: &[u8],
add_docids: Option<&RoaringBitmap>,
del_docids: Option<&RoaringBitmap>,
) -> Result<bool>
pub fn modify( &self, txn: &mut RwTxn<'_>, field_id: u16, facet_value: &[u8], add_docids: Option<&RoaringBitmap>, del_docids: Option<&RoaringBitmap>, ) -> Result<bool>
Modify the given facet value and corresponding document ids in the database. If no more document ids correspond to the facet value, delete it completely.
Return
Returns true if some tree-nodes of the highest level have been removed or added implying a potential
addition or deletion of a facet level.
Otherwise returns false if the tree-nodes have been modified in place.