pub struct GrenadParameters {
pub chunk_compression_type: CompressionType,
pub chunk_compression_level: Option<u32>,
pub max_memory: Option<usize>,
pub max_nb_chunks: Option<usize>,
}Fields
chunk_compression_type: CompressionTypechunk_compression_level: Option<u32>max_memory: Option<usize>max_nb_chunks: Option<usize>Implementations
Sourceimpl GrenadParameters
impl GrenadParameters
Sourcepub fn max_memory_by_thread(&self) -> Option<usize>
pub fn max_memory_by_thread(&self) -> Option<usize>
This function use the number of threads in the current threadpool to compute the value.
This should be called inside of a rayon thread pool, otherwise, it will take the global number of threads.