WordsPrefixesFst

Struct WordsPrefixesFst 

pub struct WordsPrefixesFst<'t, 'i> { /* private fields */ }

Implementations

Source

impl<'t, 'i> WordsPrefixesFst<'t, 'i>

pub fn new( wtxn: &'t mut RwTxn<'i>, index: &'i Index, ) -> WordsPrefixesFst<'t, 'i>

pub fn threshold(&mut self, value: usize) -> &mut Self

Set the number of words required to make a prefix be part of the words prefixes database. If a word prefix is supposed to match more than this number of words in the dictionary, therefore this prefix is added to the words prefixes datastructures.

Default value is 100. This value must be higher than 50 and will be clamped to this bound otherwise.

pub fn max_prefix_length(&mut self, value: usize) -> &mut Self

Set the maximum length of prefixes in bytes.

Default value is 4 bytes. This value must be between 1 and 25 will be clamped to these bounds, otherwise.

pub fn execute(self) -> Result<()>