Module vector

Module vector 

Re-exports

pub use self::error::Error;

Modules

composite
error
hf
json_template
Module to manipulate JSON templates.
manual
ollama
openai
parsed_vectors
rest
settings

Structs

ArroyStats
ArroyWrapper
DistributionShift
Describes the mean and sigma of distribution of embedding similarity in the embedding space.
EmbeddingConfig
Configuration for an embedder.
EmbeddingConfigs
Map of embedder configurations.
Embeddings
One or multiple embeddings stored consecutively in a flat vector.

Enums

Embedder
An embedder can be used to transform text into embeddings.
EmbedderOptions
Options of an embedder, specific to each kind of embedder.

Constants

MAX_COMPOSITE_DISTANCE
REQUEST_PARALLELISM

Functions

arroy_db_range_for_embedder
is_cuda_enabled
Whether CUDA is supported in this version of Meilisearch.

Type Aliases

Embedding