Module json_template

Module json_template 

Module to manipulate JSON templates.

This module allows two main operations:

  1. Render JSON values from a template and a context value.
  2. Retrieve data from a template and JSON values.

Structs

ExtractionError
Error that occurs when ValueTemplate::extract fails.
MissingValue
Error that occurs when no few value was provided to a template for injection.
ValueTemplate
Encapsulates a JSON template and allows injecting and extracting values from it.

Enums

ExtractionErrorContext
Context where an extraction failure happened
ExtractionErrorKind
Kind of errors that can happen during extraction
PathComponent
Component of a path to a Value
TemplateParsingError
Error that occurs when trying to parse a template in ValueTemplate::new

Functions

path_with_root
Builds a string representation of a path, preprending the name of the root value.