pub enum ExtractionErrorContext {
ExtractingSingleValue,
FindingPathToArray,
ExtractingArrayItem(usize),
}Expand description
Context where an extraction failure happened
The operation that failed
Variants
ExtractingSingleValue
Failure happened while extracting a value at a single location
FindingPathToArray
Failure happened while extracting an array of values
ExtractingArrayItem(usize)
Failure happened while extracting a value inside of an array