pub enum ExtractionErrorKind {
MissingPathComponent {
missing_index: usize,
path: Vec<PathComponent>,
key_suggestion: Option<String>,
},
WrongPathComponent {
wrong_component: String,
index: usize,
path: Vec<PathComponent>,
},
DeserializationError {
error: Error,
path: Vec<PathComponent>,
},
}Expand description
Kind of errors that can happen during extraction
Variants
MissingPathComponent
An expected path component is missing
Fields

path: Vec<PathComponent>Path where a component is missing
WrongPathComponent
An expected path component cannot be found because its container is the wrong type
Fields

path: Vec<PathComponent>Path where a component has the wrong type
DeserializationError
Could not deserialize an extracted value to its requested type