TemplateParsingError

Enum TemplateParsingError 

pub enum TemplateParsingError {
    NestedRepeatString(Vec<PathComponent>),
    RepeatStringNotInArray(Vec<PathComponent>),
    BadIndexForRepeatString(Vec<PathComponent>, usize),
    MissingPlaceholderInRepeatedValue(Vec<PathComponent>),
    MultipleRepeatString(Vec<PathComponent>, Vec<PathComponent>),
    MultiplePlaceholderString(Vec<PathComponent>, Vec<PathComponent>),
    MissingPlaceholderString,
    BothArrayAndSingle {
        single_path: Vec<PathComponent>,
        path_to_array: Vec<PathComponent>,
        array_to_placeholder: Vec<PathComponent>,
    },
}
Error that occurs when trying to parse a template in ValueTemplate::new

Variants



NestedRepeatString(Vec<PathComponent>)

A repeat string appears inside a repeated value



RepeatStringNotInArray(Vec<PathComponent>)

A repeat string appears outside of an array



BadIndexForRepeatString(Vec<PathComponent>, usize)

A repeat string appears in an array, but not in the second position



MissingPlaceholderInRepeatedValue(Vec<PathComponent>)

A repeated value lacks a placeholder



MultipleRepeatString(Vec<PathComponent>, Vec<PathComponent>)

Multiple repeat string appear in the template



MultiplePlaceholderString(Vec<PathComponent>, Vec<PathComponent>)

Multiple placeholder strings appear in the template



MissingPlaceholderString

No placeholder string appear in the template



BothArrayAndSingle

A placeholder appears both inside a repeated value and outside of it

Fields

single_path: Vec<PathComponent>

Path to the single value

path_to_array: Vec<PathComponent>

Path to the array of repeated values

array_to_placeholder: Vec<PathComponent>

Path to placeholder inside each repeated value, starting from the array

Implementations

Source

impl TemplateParsingError

pub fn error_message( &self, root: &str, placeholder: &str, repeat: &str, ) -> String

Produce an error message from the error kind, the name of the root object, the placeholder string and the repeat string