ExtractionError

Struct ExtractionError 

pub struct ExtractionError {
    pub kind: ExtractionErrorKind,
    pub context: ExtractionErrorContext,
}
Error that occurs when ValueTemplate::extract fails.

Fields

kind: ExtractionErrorKind

The cause of the failure

context: ExtractionErrorContext

The context where the failure happened: the operation that failed

Implementations

Source

impl ExtractionError

pub fn error_message( &self, root: &str, placeholder: &str, expected_value_type: &str, ) -> String

Produce an error message from the error, the name of the root object, the placeholder string and the expected value type