ValueTemplate

Struct ValueTemplate 

pub struct ValueTemplate { /* private fields */ }
Encapsulates a JSON template and allows injecting and extracting values from it.

Implementations

Source

impl ValueTemplate

pub fn new( template: Value, placeholder_string: &str, repeat_string: &str, ) -> Result<Self, TemplateParsingError>

Prepare a template for injection or extraction.

Parameters
  • template: JSON value that acts a template. Its placeholder values will be replaced by actual values during injection, and actual values will be recovered from their location during extraction.
  • placeholder_string: Value that a JSON string should assume to act as a placeholder value that can be injected into or extracted from.
  • repeat_string: Sentinel value that can be placed as the second value in an array to indicate that the first value can be repeated any number of times. The first value should contain exactly one placeholder string.
Errors
pub fn has_array_value(&self) -> bool

Whether there is a placeholder that can be repeated.

  • During injection, all values are injected in the array placeholder,
  • During extraction, all repeatable placeholders are extracted from the array.
pub fn inject( &self, values: impl IntoIterator<Item = Value>, ) -> Result<Value, MissingValue>

Render a value from the template and context values.

Error
pub fn extract<T>(&self, value: Value) -> Result<Vec<T>, ExtractionError>
where T: for<'de> Deserialize<'de>,

Extract sub values from the template and a value.

Errors
  • if a single placeholder is missing.
  • if there is no value corresponding to an array placeholder
  • if the value corresponding to an array placeholder is not an array