pub enum ReindexAction {
RegeneratePrompts,
FullReindex,
}Expand description
Indicates what action should take place during a reindexing operation for an embedder
Variants
RegeneratePrompts
An indexing operation should take place for this embedder, keeping existing vectors and checking whether the document template changed or not
FullReindex
An indexing operation should take place for all documents for this embedder, removing existing vectors (except userProvided ones)