pub struct ArroyWrapper { /* private fields */ }Implementations
Sourceimpl ArroyWrapper
impl ArroyWrapper
pub fn new( database: Database<Unspecified>, embedder_index: u8, quantized: bool, ) -> Self
pub fn embedder_index(&self) -> u8
pub fn dimensions(&self, rtxn: &RoTxn<'_>) -> Result<usize, Error>
pub fn build_and_quantize<R: Rng + SeedableRng>( &mut self, wtxn: &mut RwTxn<'_>, progress: &Progress, rng: &mut R, dimension: usize, quantizing: bool, arroy_memory: Option<usize>, cancel: &(impl Fn() -> bool + Sync + Send), ) -> Result<(), Error>
Sourcepub fn add_items(
&self,
wtxn: &mut RwTxn<'_>,
item_id: ItemId,
embeddings: &Embeddings<f32>,
) -> Result<(), Error>
pub fn add_items( &self, wtxn: &mut RwTxn<'_>, item_id: ItemId, embeddings: &Embeddings<f32>, ) -> Result<(), Error>
Overwrite all the embeddings associated with the index and item ID.
/!\ It won’t remove embeddings after the last passed embedding, which can leave stale embeddings.
You should call del_items on the item_id before calling this method.
/!\ Cannot insert more than u8::MAX embeddings; after inserting u8::MAX embeddings, all the remaining ones will be silently ignored.
Sourcepub fn add_item(
&self,
wtxn: &mut RwTxn<'_>,
item_id: ItemId,
vector: &[f32],
) -> Result<(), Error>
pub fn add_item( &self, wtxn: &mut RwTxn<'_>, item_id: ItemId, vector: &[f32], ) -> Result<(), Error>
Add one document int for this index where we can find an empty spot.
Sourcepub fn del_items(
&self,
wtxn: &mut RwTxn<'_>,
dimension: usize,
item_id: ItemId,
) -> Result<(), Error>
pub fn del_items( &self, wtxn: &mut RwTxn<'_>, dimension: usize, item_id: ItemId, ) -> Result<(), Error>
Delete all embeddings from a specific item_id
Sourcepub fn del_item(
&self,
wtxn: &mut RwTxn<'_>,
item_id: ItemId,
vector: &[f32],
) -> Result<bool, Error>
pub fn del_item( &self, wtxn: &mut RwTxn<'_>, item_id: ItemId, vector: &[f32], ) -> Result<bool, Error>
Delete one item.
pub fn clear(&self, wtxn: &mut RwTxn<'_>, dimension: usize) -> Result<(), Error>
pub fn contains_item( &self, rtxn: &RoTxn<'_>, dimension: usize, item: ItemId, ) -> Result<bool, Error>
pub fn nns_by_item( &self, rtxn: &RoTxn<'_>, item: ItemId, limit: usize, filter: Option<&RoaringBitmap>, ) -> Result<Vec<(ItemId, f32)>, Error>
pub fn nns_by_vector( &self, rtxn: &RoTxn<'_>, vector: &[f32], limit: usize, filter: Option<&RoaringBitmap>, ) -> Result<Vec<(ItemId, f32)>, Error>
pub fn item_vectors( &self, rtxn: &RoTxn<'_>, item_id: u32, ) -> Result<Vec<Vec<f32>>, Error>
pub fn aggregate_stats( &self, rtxn: &RoTxn<'_>, stats: &mut ArroyStats, ) -> Result<(), Error>