Embeddings

Struct Embeddings 

pub struct Embeddings<F> { /* private fields */ }
One or multiple embeddings stored consecutively in a flat vector.

Implementations

Source

impl<F> Embeddings<F>

pub fn new(dimension: usize) -> Self

Declares an empty vector of embeddings of the specified dimensions.

pub fn from_single_embedding(embedding: Vec<F>) -> Self

Declares a vector of embeddings containing a single element.

The dimension is inferred from the length of the passed embedding.

pub fn from_inner(data: Vec<F>, dimension: usize) -> Result<Self, Vec<F>>

Declares a vector of embeddings from its components.

data.len() must be a multiple of dimension, otherwise an error is returned.

pub fn embedding_count(&self) -> usize

Returns the number of embeddings in this vector of embeddings.

pub fn dimension(&self) -> usize

Dimension of a single embedding.

pub fn into_inner(self) -> Vec<F>

Deconstructs self into the inner flat vector.

pub fn as_inner(&self) -> &[F]

A reference to the inner flat vector.

pub fn iter(&self) -> impl Iterator<Item = &[F]> + '_

Iterates over the embeddings contained in the flat vector.

pub fn push(&mut self, embedding: Vec<F>) -> Result<(), Vec<F>>

Push an embedding at the end of the embeddings.

If embedding.len() != self.dimension, then the push operation fails.

pub fn append(&mut self, embeddings: Vec<F>) -> Result<(), Vec<F>>

Append a flat vector of embeddings at the end of the embeddings.

If embeddings.len() % self.dimension != 0, then the append operation fails.