Re-exports
pub use self::new::ChannelCongestion;
Modules
Structs
- Available
Ids - Clear
Documents - Clonable
Mmap - Wrapper around Mmap allowing to virtually clone grenad-chunks in a parallel process like the indexing.
- Concurrent
Available Ids - A concurrent ID generate that will never return the same ID twice.
- Document
Addition Result - Facets
Update Bulk - Algorithm to insert elememts into the
facet_id_(string/f64)_docidsdatabases by rebuilding the database “from scratch”. - Facets
Update Incremental Inner - Implementation of
FacetsUpdateIncrementalthat is independent of milli’sIndextype - Grenad
Parameters - Index
Documents - Index
Documents Config - Indexer
Config - Keep
First - Keep
Latest Obkv - Only the last value associated with an id is kept.
- Merge
CboRoaring Bitmaps - Do a union of all the CboRoaringBitmaps in the values.
- Merge
Deladd Btreeset String - Do a union of BtreeSet on both sides of a DelAdd obkv separately and outputs a new DelAdd with both unions.
- Merge
Deladd CboRoaring Bitmaps - Do a union of CboRoaringBitmaps on both sides of a DelAdd obkv separately and outputs a new DelAdd with both unions.
- Merge
Ignore Values - Used when trying to merge readers, but you don’t actually care about the values.
- Merge
Roaring Bitmaps - Obkvs
Keep Last Addition Merge Deletions - Merge all the obkvs deletions from the newest to the oldest and keep only the newest additions.
- Obkvs
Merge Additions AndDeletions - Merge all the obkvs from the newest to the oldest.
- Settings
- Transform
- Extract the external ids, deduplicate and compute the new internal documents ids and fields ids, writing all the documents under their internal ids into a final file.
- Transform
Output - Word
Prefix Docids - Word
Prefix Integer Docids - Words
Prefixes Fst
Enums
- Document
Id - A type that represents a document id that has been retrieved from a document or auto-generated.
- Index
Documents Method - Setting
- Update
Indexing Step
Functions
- as_
cloneable_ ⚠grenad - Safety
- create_
sorter - A helper function that creates a grenad sorter with the given parameters. The max memory is clamped to something reasonable.
- create_
writer - extract_
finite_ float_ from_ value - Try to extract an
f64from a JSONValueand return theValuein theErrvariant if it failed. - fst_
stream_ into_ hashset - Converts an fst Stream into an HashSet of Strings.
- fst_
stream_ into_ vec - grenad_
obkv_ into_ chunks - Returns an iterator that outputs grenad readers of obkv documents
with a maximum size of approximately
documents_chunks_size. - merge_
deladd_ cbo_ roaring_ bitmaps_ into_ cbo_ roaring_ bitmap - A function that merges a DelAdd of bitmao into an already existing bitmap.
- merge_
two_ del_ add_ obkvs - serialize_
roaring_ bitmap - sorter_
into_ reader - try_
split_ array_ at - Divides one slice into an array and the tail at an index,
returns
NoneifNis out of bounds. - try_
split_ at - Divides one slice into two at an index, returns
Noneif mid is out of bounds. - valid_
facet_ value - valid_
lmdb_ key - validate_
embedding_ settings - write_
sorter_ into_ database - Write provided sorter in database using serialize_value function. merge_values function is used if an entry already exist in the database.
- writer_
into_ reader