pub struct IndexDocuments<'t, 'i, 'a, FP, FA> { /* private fields */ }Implementations
Sourceimpl<'t, 'i, 'a, FP, FA> IndexDocuments<'t, 'i, 'a, FP, FA>
impl<'t, 'i, 'a, FP, FA> IndexDocuments<'t, 'i, 'a, FP, FA>
pub fn new( wtxn: &'t mut RwTxn<'i>, index: &'i Index, indexer_config: &'a IndexerConfig, config: IndexDocumentsConfig, progress: FP, should_abort: FA, ) -> Result<IndexDocuments<'t, 'i, 'a, FP, FA>>
Sourcepub fn add_documents<R: Read + Seek>(
self,
reader: DocumentsBatchReader<R>,
) -> Result<(Self, StdResult<u64, UserError>)>
pub fn add_documents<R: Read + Seek>( self, reader: DocumentsBatchReader<R>, ) -> Result<(Self, StdResult<u64, UserError>)>
Adds a batch of documents to the current builder.
Since the documents are progressively added to the writer, a failure will cause only
return an error and not the IndexDocuments struct as it is invalid to use it afterward.
Returns the number of documents added to the builder.
pub fn with_embedders(self, embedders: EmbeddingConfigs) -> Self
pub fn execute(self) -> Result<DocumentAdditionResult>
Sourcepub fn execute_raw(self, output: TransformOutput) -> Result<u64>
pub fn execute_raw(self, output: TransformOutput) -> Result<u64>
Returns the total number of documents in the index after the update.
pub fn execute_prefix_databases( self, word_docids: Option<Merger<CursorClonableMmap, MergeDeladdCboRoaringBitmaps>>, exact_word_docids: Option<Merger<CursorClonableMmap, MergeDeladdCboRoaringBitmaps>>, word_position_docids: Option<Merger<CursorClonableMmap, MergeDeladdCboRoaringBitmaps>>, word_fid_docids: Option<Merger<CursorClonableMmap, MergeDeladdCboRoaringBitmaps>>, ) -> Result<()>