pub struct Transform<'a, 'i> {
pub index: &'i Index,
pub index_documents_method: IndexDocumentsMethod,
/* private fields */
}Expand description
Extract the external ids, deduplicate and compute the new internal documents ids and fields ids, writing all the documents under their internal ids into a final file.
Outputs the new FieldsIdsMap, the new UsersIdsDocumentsIds map, the new documents ids,
the replaced documents ids, the number of documents in this update and the file
containing all those documents.
Fields
index: &'i Indexindex_documents_method: IndexDocumentsMethodImplementations
Sourceimpl<'a, 'i> Transform<'a, 'i>
impl<'a, 'i> Transform<'a, 'i>
pub fn new( wtxn: &mut RwTxn<'_>, index: &'i Index, indexer_settings: &'a IndexerConfig, index_documents_method: IndexDocumentsMethod, _autogenerate_docids: bool, ) -> Result<Self>
pub fn read_documents<R, FP, FA>( &mut self, reader: EnrichedDocumentsBatchReader<R>, wtxn: &mut RwTxn<'_>, progress_callback: FP, should_abort: FA, ) -> Result<usize>
Sourcepub fn prepare_for_documents_reindexing(
self,
wtxn: &mut RwTxn<'i>,
settings_diff: InnerIndexSettingsDiff,
) -> Result<TransformOutput>
pub fn prepare_for_documents_reindexing( self, wtxn: &mut RwTxn<'i>, settings_diff: InnerIndexSettingsDiff, ) -> Result<TransformOutput>
Clear all databases. Returns a TransformOutput with a file that contains the documents
of the index with the attributes reordered accordingly to the FieldsIdsMap given as argument.