Module to manipulate JSON templates.
This module allows two main operations:
- Render JSON values from a template and a context value.
- Retrieve data from a template and JSON values.
Structs
- Extraction
Error - Error that occurs when
ValueTemplate::extractfails. - Missing
Value - Error that occurs when no few value was provided to a template for injection.
- Value
Template - Encapsulates a JSON template and allows injecting and extracting values from it.
Enums
- Extraction
Error Context - Context where an extraction failure happened
- Extraction
Error Kind - Kind of errors that can happen during extraction
- Path
Component - Component of a path to a Value
- Template
Parsing Error - Error that occurs when trying to parse a template in
ValueTemplate::new
Functions
- path_
with_ root - Builds a string representation of a path, preprending the name of the root value.