pub struct Embeddings<F> { /* private fields */ }Expand description
One or multiple embeddings stored consecutively in a flat vector.
Implementations
Sourceimpl<F> Embeddings<F>
impl<F> Embeddings<F>
Sourcepub fn new(dimension: usize) -> Self
pub fn new(dimension: usize) -> Self
Declares an empty vector of embeddings of the specified dimensions.
Sourcepub fn from_single_embedding(embedding: Vec<F>) -> Self
pub fn from_single_embedding(embedding: Vec<F>) -> Self
Declares a vector of embeddings containing a single element.
The dimension is inferred from the length of the passed embedding.
Sourcepub fn from_inner(data: Vec<F>, dimension: usize) -> Result<Self, Vec<F>>
pub fn from_inner(data: Vec<F>, dimension: usize) -> Result<Self, Vec<F>>
Declares a vector of embeddings from its components.
data.len() must be a multiple of dimension, otherwise an error is returned.
Sourcepub fn embedding_count(&self) -> usize
pub fn embedding_count(&self) -> usize
Returns the number of embeddings in this vector of embeddings.
Sourcepub fn into_inner(self) -> Vec<F>
pub fn into_inner(self) -> Vec<F>
Deconstructs self into the inner flat vector.
Sourcepub fn iter(&self) -> impl Iterator<Item = &[F]> + '_
pub fn iter(&self) -> impl Iterator<Item = &[F]> + '_
Iterates over the embeddings contained in the flat vector.